Package: testPackage
Title: A Testing Package Only
Version: 0.0.0.9000
Authors@R: 
    person("First", "Last", , "first.last@example.com", role = c("aut", "cre"),
           comment = c(ORCID = "YOUR-ORCID-ID"))
Maintainer: Dummy <dummy@example.com>
Author: Dummy <dummy@example.com>
Description: What the package does (one paragraph).
License: MIT + file LICENSE
Encoding: UTF-8
Roxygen: list(markdown = TRUE, 
         roclets = c("collate", "rd", "namespace", "doctest::dt_roclet")) 
RoxygenNote: 7.2.3
Suggests: testthat
