# @doctestExample

    # Generated by doctest: do not edit by hand
    # Please edit file in R/<text>
    
    test_that("example from a file", {
      # Created from @doctest for `foo`
      # Source file: <text>
      # Source line: 4
      expect_equal(1 + 1, 2)
    })
    

---

    $foo.Rd
    % Generated by roxygen2: do not edit by hand
    % Please edit documentation in ./<text>
    \name{foo}
    \alias{foo}
    \title{Title}
    \usage{
    foo()
    }
    \description{
    Title
    }
    \examples{
    1 + 1
    
    some_code_that_might_go_in_an_example()
    }
    

