# Rd output

    $foo.Rd
    % Generated by roxygen2: do not edit by hand
    % Please edit documentation in ./<text>
    \name{foo}
    \alias{foo}
    \title{Title}
    \usage{
    foo()
    }
    \description{
    Title
    }
    \examples{
    x <- 1
    x
    -x
    }
    

---

    $foo.Rd
    % Generated by roxygen2: do not edit by hand
    % Please edit documentation in ./<text>
    \name{foo}
    \alias{foo}
    \title{Title}
    \usage{
    foo()
    }
    \description{
    Title
    }
    \examples{
    x <- 1
    if (x > 0) {
      x
    } else {
      -x
    }
    }
    

# dontrun

    $foo.Rd
    % Generated by roxygen2: do not edit by hand
    % Please edit documentation in ./<text>
    \docType{data}
    \name{foo}
    \alias{foo}
    \title{Title}
    \format{
    An object of class \code{numeric} of length 1.
    }
    \usage{
    foo
    }
    \description{
    Title
    }
    \keyword{datasets}
    \examples{
    \dontrun{
    stop('foo')
    }
    }
    

