# @doctest

    # Generated by doctest: do not edit by hand
    # Please edit file in R/<text>
    
    test_that("is 1 1?", {
      # Created from @doctest for `unknown`
      # Source file: <text>
      # Source line: 2
      expect_equal(1, 1)
    })
    
    test_that("is TRUE true?", {
      # Created from @doctest for `unknown`
      # Source file: <text>
      # Source line: 5
      expect_true(TRUE)
    })
    

# dontrun

    # Generated by doctest: do not edit by hand
    # Please edit file in R/<text>
    
    test_that("Doctest: unknown", {
      # Created from @doctest for `unknown`
      # Source file: <text>
      # Source line: 2
      expect_error(stop("foo"), "foo")
    })
    

