# @expectation

    # Generated by doctest: do not edit by hand
    # Please edit file in R/<text>
    
    test_that("Doctest: unknown", {
      # Created from @doctest for `unknown`
      # Source file: <text>
      # Source line: 2
      expect_equal(sum(1, 1), 2)
    })
    

---

    # Generated by doctest: do not edit by hand
    # Please edit file in R/<text>
    
    test_that("Doctest: unknown", {
      # Created from @doctest for `unknown`
      # Source file: <text>
      # Source line: 2
      expect_equal(sum(1, 1), 2)
    })
    

---

    # Generated by doctest: do not edit by hand
    # Please edit file in R/<text>
    
    test_that("Doctest: unknown", {
      # Created from @doctest for `unknown`
      # Source file: <text>
      # Source line: 2
      expect_equal(1 + 1, 2)
    })
    

---

    # Generated by doctest: do not edit by hand
    # Please edit file in R/<text>
    
    test_that("Doctest: unknown", {
      # Created from @doctest for `unknown`
      # Source file: <text>
      # Source line: 2
      expect_equal(base::sum(1, 1), 2)
    })
    

---

    # Generated by doctest: do not edit by hand
    # Please edit file in R/<text>
    
    test_that("Doctest: unknown", {
      # Created from @doctest for `unknown`
      # Source file: <text>
      # Source line: 2
      expect_equal(sum(1, 1), 2)
    })
    

---

    # Generated by doctest: do not edit by hand
    # Please edit file in R/<text>
    
    test_that("Doctest: unknown", {
      # Created from @doctest for `unknown`
      # Source file: <text>
      # Source line: 2
      expect_equal(2 %plus% 2, 4)
    })
    

