% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/safe-arithmetic.R
\name{safe_mean}
\alias{safe_mean}
\title{Safe mean}
\usage{
safe_mean(x)
}
\arguments{
\item{x}{Numeric vector}
}
\value{
Mean of \code{x}
}
\description{
Safe mean
}
\examples{
x <- 1:3
safe_mean(x)

safe_mean("a")
safe_mean(c(1, NA))
}
