% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/palindrome.R
\name{palindrome}
\alias{palindrome}
\alias{palindrome_letters}
\title{Return a palindrome}
\usage{
palindrome()

palindrome_letters()
}
\value{
A string
}
\description{
Return a palindrome
}
\examples{
p <- palindrome()

print(p)
pal_letters <- p |>
  tolower() |>
  (\(x) gsub("[^A-z]", "", x))() |>
  strsplit("") |>
  unlist()



tenet <- palindrome_letters()
}
